@@ -18,7 +18,6 @@ module Test.Hspec.Core.Config (
 import           Prelude ()
 import           Test.Hspec.Core.Compat
 
-import           GHC.IO.Exception (IOErrorType(UnsupportedOperation))
 import           System.IO
 import           System.IO.Error
 import           System.Exit
@@ -61,7 +60,7 @@ applyFailureReport mFailureReport config = config {
   }
   where
 
-    mSeed = configSeed config <|> deprecatedQuickCheckSeed config <|> (failureReportSeed <$> mFailureReport)
+    mSeed = getSeed config <|> (failureReportSeed <$> mFailureReport)
     mMaxSuccess = configQuickCheckMaxSuccess config <|> (failureReportMaxSuccess <$> mFailureReport)
     mMaxSize = configQuickCheckMaxSize config <|> (failureReportMaxSize <$> mFailureReport)
     mMaxDiscardRatio = configQuickCheckMaxDiscardRatio config <|> (failureReportMaxDiscardRatio <$> mFailureReport)
@@ -149,13 +148,13 @@ readConfigFiles = do
 
 readGlobalConfigFile :: IO (Maybe ConfigFile)
 readGlobalConfigFile = do
-  mHome <- tryJust (guard . isPotentialHomeDirError) getHomeDirectory
+  mHome <- tryJust (guard . unavailable) getHomeDirectory
   case mHome of
     Left _ -> return Nothing
     Right home -> readConfigFile (home </> ".hspec")
   where
-    isPotentialHomeDirError e =
-      isDoesNotExistError e || ioeGetErrorType e == UnsupportedOperation
+    unavailable :: IOError -> Bool
+    unavailable e = isDoesNotExistError e || isUnsupportedOperation e
 
 readLocalConfigFile :: IO (Maybe ConfigFile)
 readLocalConfigFile = do
