@@ -3,16 +3,29 @@ module Test.Hspec.Core.Config.Definition (
   Config(..)
 , ColorMode(..)
 , UnicodeMode(..)
-, filterOr
 , mkDefaultConfig
 
+, filterOr
+
+, setConfigAnnotation
+, getConfigAnnotation
+
+, addExtensionOptions
+, getExtensionOptions
+
+, getSeed
+#ifdef ENABLE_LEGACY_V1_FORMATTERS
+, getFormatter
+#endif
+
 , commandLineOnlyOptions
 , formatterOptions
 , smallCheckOptions
 , quickCheckOptions
 , runnerOptions
 
-, deprecatedQuickCheckSeed
+, flag
+, option
 
 #ifdef TEST
 , splitOn
@@ -26,13 +39,43 @@ import           System.Directory (getTemporaryDirectory, removeFile)
 import           System.IO (openTempFile, hClose)
 import           System.Process (system)
 
+import           Test.Hspec.Core.Annotations (Annotations)
+import qualified Test.Hspec.Core.Annotations as Annotations
+
 import           Test.Hspec.Core.Format (Format, FormatConfig)
 import           Test.Hspec.Core.Formatters.Pretty (pretty2)
+#ifdef ENABLE_LEGACY_V1_FORMATTERS
 import qualified Test.Hspec.Core.Formatters.V1.Monad as V1
+import qualified Test.Hspec.Core.Formatters.V1.Internal as V1 (formatterToFormat)
+#endif
 import           Test.Hspec.Core.Util
 
 import           GetOpt.Declarative
 
+setConfigAnnotation :: Typeable value => value -> Config -> Config
+setConfigAnnotation value config = config { configAnnotations = Annotations.setValue value $ configAnnotations config }
+
+getConfigAnnotation :: Typeable value => Config -> Maybe value
+getConfigAnnotation = Annotations.getValue . configAnnotations
+
+newtype ExtensionOptions = ExtensionOptions { unExtensionOptions :: [(String, [Option Config])] }
+
+addExtensionOptions :: String -> [Option Config] -> Config -> Config
+addExtensionOptions section opts config = setExtensionOptions ((section, opts) : getExtensionOptions config) config
+
+setExtensionOptions :: [(String, [Option Config])] -> Config -> Config
+setExtensionOptions = setConfigAnnotation . ExtensionOptions
+
+getExtensionOptions :: Config -> [(String, [Option Config])]
+getExtensionOptions = maybe [] unExtensionOptions . getConfigAnnotation
+
+#ifdef ENABLE_LEGACY_V1_FORMATTERS
+getFormatter :: Config -> Maybe (FormatConfig -> IO Format)
+getFormatter config = configFormat config <|> V1.formatterToFormat <$> configFormatter config
+#endif
+
+getSeed :: Config -> Maybe Integer
+getSeed config = configSeed config <|> configQuickCheckSeed config
 
 data ColorMode = ColorAuto | ColorNever | ColorAlways
   deriving (Eq, Show)
@@ -88,16 +131,18 @@ data Config = Config {
 , configExpertMode :: Bool -- ^ @since 2.11.2
 , configAvailableFormatters :: [(String, FormatConfig -> IO Format)] -- ^ @since 2.9.0
 , configFormat :: Maybe (FormatConfig -> IO Format)
+#ifdef ENABLE_LEGACY_V1_FORMATTERS
 , configFormatter :: Maybe V1.Formatter
+#endif
 , configHtmlOutput :: Bool
 , configConcurrentJobs :: Maybe Int
+, configAnnotations :: Annotations
 }
+#ifdef ENABLE_LEGACY_V1_FORMATTERS
 {-# DEPRECATED configFormatter "Use [@useFormatter@](https://hackage.haskell.org/package/hspec-api/docs/Test-Hspec-Api-Formatters-V1.html#v:useFormatter) instead." #-}
+#endif
 {-# DEPRECATED configQuickCheckSeed "Use `configSeed` instead." #-}
 
-deprecatedQuickCheckSeed :: Config -> Maybe Integer
-deprecatedQuickCheckSeed = configQuickCheckSeed
-
 mkDefaultConfig :: [(String, FormatConfig -> IO Format)] -> Config
 mkDefaultConfig formatters = Config {
   configIgnoreConfigFile = False
@@ -135,9 +180,12 @@ mkDefaultConfig formatters = Config {
 , configExpertMode = False
 , configAvailableFormatters = formatters
 , configFormat = Nothing
+#ifdef ENABLE_LEGACY_V1_FORMATTERS
 , configFormatter = Nothing
+#endif
 , configHtmlOutput = False
 , configConcurrentJobs = Nothing
+, configAnnotations = mempty
 }
 
 defaultDiffContext :: Int
@@ -160,7 +208,7 @@ withTempFile dir file contents action = do
 option :: String -> OptionSetter config -> String -> Option config
 option name arg help = Option name Nothing arg help True
 
-flag :: String -> (Bool -> Config -> Config) -> String -> Option Config
+flag :: String -> (Bool -> config -> config) -> String -> Option config
 flag name setter = option name (Flag setter)
 
 mkOptionNoArg :: String -> Maybe Char -> (Config -> Config) -> String -> Option Config
@@ -172,7 +220,7 @@ mkOption name shortcut arg help = Option name shortcut arg help True
 undocumented :: Option config -> Option config
 undocumented opt = opt {optionDocumented = False}
 
-argument :: String -> (String -> Maybe a) -> (a -> Config -> Config) -> OptionSetter Config
+argument :: String -> (String -> Maybe a) -> (a -> config -> config) -> OptionSetter config
 argument name parser setter = Arg name $ \ input c -> flip setter c <$> parser input
 
 formatterOptions :: [(String, FormatConfig -> IO Format)] -> [Option Config]
@@ -348,9 +396,9 @@ runnerOptions = [
 
   , flag "fail-fast" setFailFast "abort on first failure"
   , flag "randomize" setRandomize "randomize execution order"
-  , mkOptionNoArg "rerun" (Just 'r') setRerun "rerun all examples that failed in the previous test run (only works in combination with --failure-report or in GHCi)"
+  , (flag "rerun" setRerun "rerun all examples that failed in the previous test run (only works in combination with --failure-report or in GHCi)") {optionShortcut = Just 'r'}
   , option "failure-report" (argument "FILE" return setFailureReport) "read/write a failure report for use with --rerun"
-  , mkOptionNoArg "rerun-all-on-success" Nothing setRerunAllOnSuccess "run the whole test suite after a previously failing rerun succeeds for the first time (only works in combination with --rerun)"
+  , flag "rerun-all-on-success" setRerunAllOnSuccess "run the whole test suite after a previously failing rerun succeeds for the first time (only works in combination with --rerun)"
   , mkOption "jobs" (Just 'j') (argument "N" readMaxJobs setMaxJobs) "run at most N parallelizable tests simultaneously (default: number of available processors)"
   , option "seed" (argument "N" readMaybe setSeed) "used seed for --randomize and QuickCheck properties"
   ]
@@ -421,8 +469,11 @@ runnerOptions = [
     setRandomize :: Bool -> Config -> Config
     setRandomize value config = config {configRandomize = value}
 
-    setRerun config = config {configRerun = True}
-    setRerunAllOnSuccess config = config {configRerunAllOnSuccess = True}
+    setRerun :: Bool -> Config -> Config
+    setRerun value config = config {configRerun = value}
+
+    setRerunAllOnSuccess :: Bool -> Config -> Config
+    setRerunAllOnSuccess value config = config {configRerunAllOnSuccess = value}
 
 commandLineOnlyOptions :: [Option Config]
 commandLineOnlyOptions = [
