@@ -5,13 +5,24 @@ module Test.Hspec.Core.FailureReport (
 , readFailureReport
 ) where
 
+#if !defined(__GHCJS__) && !defined(__MHS__)
+-- ghcjs currently does not support setting environment variables
+-- (https://github.com/ghcjs/ghcjs/issues/263). Since writing a failure report
+-- into the environment is a non-essential feature we just disable this to be
+-- able to run hspec test-suites with ghcjs at all. Should be reverted once
+-- the issue is fixed.
+#define HAS_SET_ENV
+#endif
+
+
 import           Prelude ()
 import           Test.Hspec.Core.Compat
 
-#ifndef __GHCJS__
-import           System.SetEnv (setEnv)
+#ifdef HAS_SET_ENV
+import           System.Environment (setEnv)
 import           Test.Hspec.Core.Util (safeTry)
 #endif
+
 import           System.IO
 import           System.Directory
 import           Test.Hspec.Core.Util (Path)
@@ -29,20 +40,15 @@ writeFailureReport :: Config -> FailureReport -> IO ()
 writeFailureReport config report = case configFailureReport config of
   Just file -> writeFile file (show report)
   Nothing -> do
-#ifdef __GHCJS__
-    -- ghcjs currently does not support setting environment variables
-    -- (https://github.com/ghcjs/ghcjs/issues/263). Since writing a failure report
-    -- into the environment is a non-essential feature we just disable this to be
-    -- able to run hspec test-suites with ghcjs at all. Should be reverted once
-    -- the issue is fixed.
-    pass
-#else
+#ifdef HAS_SET_ENV
     -- on Windows this can throw an exception when the input is too large, hence
     -- we use `safeTry` here
     safeTry (setEnv "HSPEC_FAILURES" $ show report) >>= either onError return
     where
       onError err = do
         hPutStrLn stderr ("WARNING: Could not write environment variable HSPEC_FAILURES (" ++ show err ++ ")")
+#else
+    pass
 #endif
 
 readFailureReport :: Config -> IO (Maybe FailureReport)
