@@ -60,7 +60,7 @@ import           Test.Hspec.Core.Compat
 
 import qualified System.IO as IO
 import           System.IO (stdout)
-import           System.Console.ANSI
+import           System.Console.ANSI hiding (clearLine)
 import           Control.Monad.Trans.Reader (ReaderT(..), ask)
 import           Control.Monad.IO.Class
 import           Data.Char (isSpace)
@@ -271,10 +271,19 @@ getExpectedTotalCount = getConfigValue formatConfigExpectedTotalCount
 writeTransient :: String -> FormatM ()
 writeTransient new = do
   reportProgress <- getConfigValue formatConfigReportProgress
-  when reportProgress $ do
-    write new
-    liftIO $ IO.hFlush stdout
-    write $ "\r" ++ replicate (length new) ' ' ++ "\r"
+  when reportProgress . liftIO $ do
+    bracket_ disableLineWrapping enableLineWrapping $ writePlain new
+    IO.hFlush stdout
+    clearLine
+  where
+    disableLineWrapping :: IO ()
+    disableLineWrapping = writePlain "\ESC[?7l"
+
+    enableLineWrapping :: IO ()
+    enableLineWrapping = writePlain "\ESC[?7h"
+
+    clearLine :: IO ()
+    clearLine = writePlain "\r\ESC[K"
 
 -- | Append some output to the report.
 write :: String -> FormatM ()
@@ -288,7 +297,7 @@ splitLines = groupBy (\ a b -> isNewline a == isNewline b)
 writeChunk :: String -> FormatM ()
 writeChunk str = do
   let
-    plainOutput = IO.hPutStr stdout str
+    plainOutput = writePlain str
     colorOutput color = bracket_ (hSetSGR stdout [color]) (hSetSGR stdout [Reset]) plainOutput
   mColor <- gets stateColor
   liftIO $ case mColor of
@@ -296,6 +305,9 @@ writeChunk str = do
     Just color -> colorOutput color
     Nothing -> plainOutput
 
+writePlain :: String -> IO ()
+writePlain = IO.hPutStr stdout
+
 -- | Set output color to red, run given action, and finally restore the default
 -- color.
 withFailColor :: FormatM a -> FormatM a
@@ -359,9 +371,14 @@ missingChunk s = do
     missing = diffColorize Green "hspec-success"
 
 diffColorize :: Color -> String -> String-> FormatM ()
-diffColorize color cls s = withColor (SetColor layer Dull color) cls $ do
-  write s
+diffColorize color cls s = withColor (SetColor layer Dull color) cls $ case s of
+  "" -> write eraseInLine
+  _ -> write s
   where
+    eraseInLine :: String
+    eraseInLine = "\ESC[K"
+
+    layer :: ConsoleLayer
     layer
       | all isSpace s = Background
       | otherwise = Foreground
