@@ -1,9 +1,9 @@
 module Test.Hspec.Core.FailureReportSpec (spec) where
 
+import           Prelude ()
 import           Helper
 
 import           System.IO
-import qualified Control.Exception as E
 import           Test.Hspec.Core.FailureReport
 import           Test.Hspec.Core.Config
 
@@ -11,7 +11,7 @@ spec :: Spec
 spec = do
   describe "writeFailureReport" $ do
     it "prints a warning on unexpected exceptions" $ do
-      r <- hCapture_ [stderr] $ writeFailureReport defaultConfig (E.throw (E.ErrorCall "some error"))
+      r <- hCapture_ [stderr] $ writeFailureReport defaultConfig (throw (ErrorCall "some error"))
       r `shouldBe` "WARNING: Could not write environment variable HSPEC_FAILURES (some error)\n"
 
   describe "readFailureReport" $ do
