@@ -1,3 +1,4 @@
+{-# OPTIONS_GHC -fno-warn-deprecations #-}
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE ScopedTypeVariables #-}
 {-# LANGUAGE TypeFamilies #-}
@@ -27,6 +28,7 @@ import qualified Test.QuickCheck as QC
 import qualified Test.Hspec.Core.Hooks as H
 
 import           Test.Hspec.Core.Formatters.Pretty.ParserSpec (Person(..))
+import           Test.Hspec.Core.Extension ()
 
 runPropFoo :: [String] -> IO String
 runPropFoo args = unlines . normalizeSummary . lines <$> do
@@ -35,7 +37,7 @@ runPropFoo args = unlines . normalizeSummary . lines <$> do
       property (/= (23 :: Int))
 
 person :: Int -> Person
-person = Person "Joe"
+person age = Person "Joe" age Nothing
 
 data MyException = MyException
   deriving (Eq, Show)
@@ -527,11 +529,13 @@ spec = do
           , "  1) foo"
           , "       expected: Person {"
           , "                   personName = \"Joe\","
-          , "                   personAge = 42"
+          , "                   personAge = 42,"
+          , "                   personAddress = Nothing"
           , "                 }"
           , "        but got: Person {"
           , "                   personName = \"Joe\","
-          , "                   personAge = 23"
+          , "                   personAge = 23,"
+          , "                   personAddress = Nothing"
           , "                 }"
           , ""
           , "  To rerun use: --match \"/foo/\" --seed 0"
@@ -561,8 +565,8 @@ spec = do
           H.it "foo" $ do
             person 23 `H.shouldBe` person 42
         r `shouldContain` unlines [
-            "       expected: Person {personName = \"Joe\", personAge = 42}"
-          , "        but got: Person {personName = \"Joe\", personAge = 23}"
+            "       expected: Person {personName = \"Joe\", personAge = 42, personAddress = Nothing}"
+          , "        but got: Person {personName = \"Joe\", personAge = 23, personAddress = Nothing}"
           ]
 
     context "when formatting exceptions" $ do
@@ -596,7 +600,7 @@ spec = do
             , "  1) foo"
             , "       uncaught exception: MyException"
             , "       my exception"
-#if MIN_VERSION_base(4,20,0)
+#if MIN_VERSION_base(4,20,0) && !MIN_VERSION_base(4,21,0)
             , "       HasCallStack backtrace:"
             , "       "
 #endif
